=== added directory 'django_messages_wl'
=== added file 'django_messages_wl/__init__.py'
=== added file 'django_messages_wl/apps.py'
--- django_messages_wl/apps.py	1970-01-01 00:00:00 +0000
+++ django_messages_wl/apps.py	2018-04-03 18:57:40 +0000
@@ -0,0 +1,11 @@
+from django_messages.apps import DjangoMessagesConfig
+from django.db.models import signals
+
+
+class WLDjangoMessagesConfig(DjangoMessagesConfig):
+
+    verbose_name = 'WL Messages'
+
+    def ready(self):
+        from django_messages_wl.management import create_notice_types
+        signals.post_migrate.connect(create_notice_types, sender=self)    
\ No newline at end of file

=== added file 'django_messages_wl/management.py'
--- django_messages_wl/management.py	1970-01-01 00:00:00 +0000
+++ django_messages_wl/management.py	2018-04-03 18:57:40 +0000
@@ -0,0 +1,16 @@
+#!/usr/bin/python
+# -*- coding: utf-8 -*-
+
+from django.conf import settings
+from django.utils.translation import ugettext_lazy as _
+
+
+if "notification" in settings.INSTALLED_APPS and getattr(settings, 'DJANGO_MESSAGES_NOTIFY', True):
+    from notification import models as notification
+
+    def create_notice_types(sender, **kwargs):
+        print("Creating wl specific noticetypes for django-messages ...")
+        notification.create_notice_type("messages_received", _("Message Received"), _("you have received a message"), default=2)
+        notification.create_notice_type("messages_reply_received", _("Reply Received"), _("you have received a reply to a message"), default=2)
+else:
+    print("Skipping creation of NoticeTypes as notification app not found")
\ No newline at end of file

=== modified file 'local_urls.py.sample'
--- local_urls.py.sample	2016-06-04 14:17:40 +0000
+++ local_urls.py.sample	2018-04-03 18:57:40 +0000
@@ -1,14 +1,14 @@
 from django.conf.urls import *
 from django.conf import settings
-
+from django.views.static import serve
 
 local_urlpatterns = [
    url(r'^wlmedia/(?P<path>.*)$',
-       'django.views.static.serve',
+       serve,
        {'document_root': settings.STATIC_MEDIA_PATH},
        name='static_media'),
    url(r'^media/(?P<path>.*)$',
-       'django.views.static.serve',
+       serve,
        {'document_root': settings.STATIC_MEDIA_PATH},
        name='static_media_pybb'),
 ]

=== added file 'pybb/apps.py'
--- pybb/apps.py	1970-01-01 00:00:00 +0000
+++ pybb/apps.py	2018-04-03 18:57:40 +0000
@@ -0,0 +1,12 @@
+from django.apps import AppConfig
+from django.db.models import signals
+
+
+class PybbConfig(AppConfig):
+
+    name = 'pybb'
+    verbose_name = 'Bulletin Board'
+
+    def ready(self):
+        from pybb.management.pybb_notifications import create_notice_types
+        signals.post_migrate.connect(create_notice_types, sender=self)

=== modified file 'pybb/management/pybb_notifications.py'
--- pybb/management/pybb_notifications.py	2018-04-03 05:18:03 +0000
+++ pybb/management/pybb_notifications.py	2018-04-03 18:57:40 +0000
@@ -1,11 +1,11 @@
-from django.db.models import signals
 
 from django.utils.translation import ugettext_noop as _
 
 try:
     from notification import models as notification
 
-    def create_notice_types(app, created_models, verbosity, **kwargs):
+    def create_notice_types(sender, **kwargs):
+        print("Creating noticetypes for pybb ...")
         notification.create_notice_type('forum_new_topic',
                                         _('Forum New Topic'),
                                         _('a new topic has been added to the forum'),
@@ -13,8 +13,5 @@
         notification.create_notice_type('forum_new_post',
                                         _('Forum New Post'),
                                         _('a new comment has been posted to a topic you observe'))
-
-    signals.post_migrate.connect(create_notice_types,
-                                sender=notification)
 except ImportError:
     print 'Skipping creation of NoticeTypes as notification app not found'

=== modified file 'settings.py'
--- settings.py	2018-04-03 05:18:03 +0000
+++ settings.py	2018-04-03 18:57:40 +0000
@@ -91,7 +91,7 @@
     'wlsearch',
     'wlpoll',
     'wlevents',
-    'wlmaps',
+    'wlmaps.apps.WlMapsConfig',
     'wlscreens',
     'wlggz',
     'wlscheduling',
@@ -99,15 +99,16 @@
     'haystack', # search engine; see option HAYSTACK_CONNECTIONS
 
     # Modified 3rd party apps
-    'wiki',  # This is based on wikiapp, but has some local modifications
+    'wiki.apps.WikiConfig',  # This is based on wikiapp, but has some local modifications
     'news',  # This is based on simple-blog, but has some local modifications
     'news.managers',
-    'pybb',  # Feature enriched version of pybb
+    'pybb.apps.PybbConfig',  # Feature enriched version of pybb
 
     # Thirdparty apps
     'threadedcomments',  # included as wlapp
     'notification',     # included as wlapp
-    'django_messages',
+    #'django_messages',
+    'django_messages_wl.apps.WLDjangoMessagesConfig',
     'linaro_django_pagination',
     'tagging',
     'djangoratings',    # included as wlapp

=== modified file 'wiki/__init__.py'
--- wiki/__init__.py	2018-04-03 05:18:03 +0000
+++ wiki/__init__.py	2018-04-03 18:57:40 +0000
@@ -1,4 +0,0 @@
-#from wiki.templatetags.restructuredtext import restructuredtext
-
-#restructuredtext('`Available as 1.0 since September, 2007 <http://www.modwsgi.org/>`')
-default_app_config = 'wiki.apps.WikiConfig'
\ No newline at end of file

=== modified file 'wiki/apps.py'
--- wiki/apps.py	2018-04-03 06:34:54 +0000
+++ wiki/apps.py	2018-04-03 18:57:40 +0000
@@ -3,12 +3,10 @@
 
 
 class WikiConfig(AppConfig):
-    
+
     name = 'wiki'
     verbose_name = 'The widelands wiki'
-    
+
     def ready(self):
         from wiki.management import create_notice_types
-        from notification import models as notification
-        print("trying to ")
-        signals.post_migrate.connect(create_notice_types, sender=notification)
+        signals.post_migrate.connect(create_notice_types, sender=self)

=== modified file 'wiki/management.py'
--- wiki/management.py	2018-04-03 05:18:03 +0000
+++ wiki/management.py	2018-04-03 18:57:40 +0000
@@ -1,12 +1,11 @@
-from django.db.models import signals
 
 from django.utils.translation import ugettext_noop as _
 
 try:
     from notification import models as notification
 
-    def create_notice_types(app, created_models, verbosity, **kwargs):
-        print("Creating noticetypes!!!!!!")
+    def create_notice_types(sender, **kwargs):
+        print("Creating noticetypes for wiki ...")
         notification.create_notice_type('wiki_revision_reverted',
                                         _('Article Revision Reverted'),
                                         _('your revision has been reverted'))

=== added file 'wlmaps/apps.py'
--- wlmaps/apps.py	1970-01-01 00:00:00 +0000
+++ wlmaps/apps.py	2018-04-03 18:57:40 +0000
@@ -0,0 +1,13 @@
+from django.apps import AppConfig
+from django.db.models import signals
+
+
+class WlMapsConfig(AppConfig):
+
+    name = 'wlmaps'
+    verbose_name = 'Widelands Maps'
+
+    def ready(self):
+        from wlmaps.management import create_notice_types
+        signals.post_migrate.connect(create_notice_types, sender=self)
+

=== modified file 'wlmaps/management.py'
--- wlmaps/management.py	2018-04-03 05:18:03 +0000
+++ wlmaps/management.py	2018-04-03 18:57:40 +0000
@@ -1,16 +1,13 @@
-from django.db.models import signals
 
 from django.utils.translation import ugettext_noop as _
 
 try:
     from notification import models as notification
 
-    def create_notice_types(app, created_models, verbosity, **kwargs):
+    def create_notice_types(sender, **kwargs):
+        print('Creating notice types for maps ...')
         notification.create_notice_type('maps_new_map',
                                         _('A new Map is available'),
-                                        _('a new map is available for download'),1)
-
-    signals.post_migrate.connect(create_notice_types,
-                                sender=notification)
+                                        _('a new map is available for download'), 1)
 except ImportError:
     print 'Skipping creation of NoticeTypes as notification app not found'

